@@ -12,9 +12,7 @@ function savevar (n,v)
    else
     write("{}\n")
     v.__visited__ = n
-    local r,f
-    r,f = next(v,nil)
-    while r ~= nil do
+    for r,f in v do
       if r ~= "__visited__" then
         if type(r) == 'string' then
           savevar(n.."."..r,f)
@@ -22,7 +20,6 @@ function savevar (n,v)
           savevar(n.."["..r.."]",f)
 	end
       end
-      r,f = next(v,r)
     end
    end
  else write(tostring(v)) end
@@ -31,14 +28,10 @@ end
 
 function save ()
  write("\n-- global environment\n")
- local n,v = nextvar(nil)
-  while n ~= nil do 
-    savevar(n,v) 
-    n,v = nextvar(n)
-  end
+ foreach(globals(),savevar)
 end
 
--- ow some examples
+-- an example
 
 a = 3
 x = {a = 4, b = "name", l={4,5,67}}
